BlurredRoundedRectangle

Struct BlurredRoundedRectangle 

pub struct BlurredRoundedRectangle {
    pub rect: Rect,
    pub color: AlphaColor<Srgb>,
    pub radius: f32,
    pub std_dev: f32,
    pub invert: bool,
}
A blurred, rounded rectangle.

Fields

rect: Rect

The base rectangle to use for the blur effect.

color: AlphaColor<Srgb>

The color of the blurred rectangle.

radius: f32

The radius of the rounded rectangle’s corners.

std_dev: f32

The standard deviation of the blur effect.

invert: bool

Whether to paint the inverse (1 - alpha) of the blur coverage.

When true, the paint is fully opaque outside the blurred rectangle and fades to transparent inside it. This is useful for implementing inset box shadows.